@@ -74,6 +74,22 @@ class EnhancedZohoAnalyticsClient(report_client.ReportClient):
         return table_metadata
 
     def create_table(self, table_design, database_name=None) -> MutableMapping:
+        """
+        ZOHO_DATATYPE
+            (Supported data types are:
+            PLAIN
+            MULTI_LINE
+            EMAIL
+            NUMBER
+            POSITIVE_NUMBER
+            DECIMAL_NUMBER
+            CURRENCY
+            PERCENT
+            DATE
+            BOOLEAN
+            URL
+            AUTO_NUMBER
+        """
         db_uri = self.getDBURI(self.login_email_id, database_name or self.default_databasename)
         columns = table_design['COLUMNS']
         BIG_NUMBER_OF_COLUMNS = 10
@@ -97,7 +113,9 @@ class EnhancedZohoAnalyticsClient(report_client.ReportClient):
                     database_name: Optional[str] = None,
                     retry_limit=None,
                     date_format=None) -> Optional[report_client.ImportResult]:
-        """ data is a csv-style string, newline separated. Matching columns is a comma separated string"""
+        """ data is a csv-style string, newline separated. Matching columns is a comma separated string
+        import_mode is one of TRUNCATEADD, APPEND, UPDATEADD
+        """
         retry_count = 0
         retry_limit = retry_limit or self.default_retries
         impResult = None
@@ -108,9 +126,6 @@ class EnhancedZohoAnalyticsClient(report_client.ReportClient):
         impResult = self.importData_v2(uri, import_mode=import_mode, import_content=import_content_demojized,
                                        date_format=date_format,
                                        matching_columns=matching_columns, retry_countdown=retry_limit)
-        # logger.debug(
-        #     f"Table: {table_name}: Processed Rows: "
-        #     f"{impResult.totalRowCount} with {impResult.warningCount} warnings ")
 
         return impResult
 
@@ -138,10 +153,29 @@ class EnhancedZohoAnalyticsClient(report_client.ReportClient):
         reader = csv.DictReader(returned_data)
         return reader
 
-    def delete_rows(self, table_name, sql, database_name: Optional[str] = None, retry_countdown=5):
-        """ criteria is SQL fragments such as 'a' in ColA """
+    def delete_rows(self, table_name, sql, database_name: Optional[str] = None, retry_countdown=5)->int:
+        """ criteria is SQL fragments such as 'a' in ColA, for example,
+        sql = f"{id_column} IN ('ce76dc3a-bac0-47dd-841a-70e66613958e')
+        return the count of eows
+        """
+
+        if len(sql) > 5000:
+            raise RuntimeError("The SQL passed to delete_rows is too big and will cause Zoho 400 errors")
         uri = self.getURI(dbOwnerName=self.login_email_id, dbName=database_name or self.default_databasename,
                           tableOrReportName=table_name)
+        row_count = self.deleteData(tableURI=uri, criteria=sql, retry_countdown=retry_countdown)
+        return row_count
 
-        r = self.deleteData(tableURI=uri, criteria=sql, retry_countdown=retry_countdown)
-        return r
+    def pre_delete_rows(self, table_name, sql, database_name: Optional[str] = None, retry_countdown=5):
+        """ uses the same sql input as delete_rows and counts what is present in the table. This is to check the nbr of rows deleted is correct.
+        Zoho sometimes gets table corruption which means rows don't delete.
+        When the operation is critical, you can use this function to check the nbr of rows deleted is correct.
+        """
+
+        if len(sql) > 5000:
+            raise RuntimeError("The SQL passed to delete_rows is too big and will cause Zoho 400 errors")
+        sql = f"select count(*) from {table_name} where {sql}"
+        reader = self.data_export_using_sql(sql,table_name=table_name)
+        result = list(reader)[0]
+        row_count = int(result['count(*)'])
+        return row_count
\ No newline at end of file
